OC.L10N.register(
    "activity",
    {
    "Personal activity feed for %s" : "הזנת פעילות עצמית עבור %s",
    "Your feed URL is invalid" : "כתובת ההזנה שגויה",
    "Activity feed for %1$s" : "ערוץ פעילות עבור %1$s",
    "Activity feed" : "דיווחי פעילות",
    "Your settings have been updated." : "ההגדרות שלך עודכנו",
    "Settings have been updated." : "ההגדרות עודכנו",
    "remote user" : "משתמש מרוחק",
    "Recent activity" : "פעילות אחרונה",
    "No activities" : "אין פעילויות",
    "More activities" : "פעילויות נוספות",
    "Daily activity summary for %s" : "סיכום פעילות יומית עבור %s",
    "You can disable daily digest emails in the <a href=\"%s\">settings</a>." : "אתה יכול לבטל את תמצית האימיילים <a href=\"%s\">בהגדרות</a>.",
    "You can disable daily digest emails in the settings: %s" : "אתה יכול לבטל את תמצית האימיילים היומית בהגדרות: %s",
    "All activities" : "כל הפעילויות",
    "By others" : "על ידי אחרים",
    "By you" : "על ידך",
    "Activity at %s" : "פעילות ב %s",
    "Hello %s" : "שלום %s",
    "Hello %s," : "שלום %s,",
    "There was some activity at %s" : "הייתה פעילות ב%s",
    "_and %n more _::_and %n more _" : ["ו־%n נוסף","ו־%n נוספים","ו־%n נוספים"],
    "You can change the frequency of these emails or disable them in the <a href=\"%s\">settings</a>." : "אתה יכול לשנות את תדירות של האימיילים האלו או לבטל אותם<a href=\"%s\">בהגדרות</a>.",
    "You can change the frequency of these emails or disable them in the settings: %s" : "אתה יכול לשנות או לבטל את התדירות של האימיילים האלה בהגדרות: %s",
    "Mail" : "דואר",
    "Push" : "דחיפה",
    "Activity" : "פעילות",
    "Notifications" : "התראות",
    "This application enables people to view a log of activities about them, their files or other data." : "היישום הזה מאפשר לאנשים לצפות ביומן פעילויות שלהם, הקבצים שלהם או נתונים אחרים.",
    "This app allows people to see actions related to their files and data in Nextcloud.\n\t\tEach person can configure their individual activity settings in the personal settings,\n\t\tto choose which activity should be pushed to mobile phones, sent via email\n\t\tor whether a daily summary is sent each morning.\n\t\tMore information is available in the Activity documentation." : "היישום מאפשר לאנשים לראות פעולות שקשורות בקבצים ובנתונים שלהם ב־Nextcloud.\n\t\tכל אחד יכול להגדיר את הגדרות הפעילות האישיות לו בהגדרות האישיות.\n\t\tכדי לבחור איזו פעילות תידחף לטלפונים, תישלח דרך דוא״ל.\n\t\tאו האם לשלוח תקציר יומי כל בוקר.\n\t\tיש עוד מידע בתיעוד הפעילות.",
    "Send email" : "שליחת דואר אלקטרוני",
    "Send push notification" : "שליחת הודעת פוש",
    "Activity notification configuration" : "הגדרת התראות פעילות",
    "Today" : "היום",
    "Yesterday" : "אתמול",
    "You need to set up your email address before you can receive notification emails." : "יש להגדיר כתובת דואר אלקטרוני לפני שניתן יהיה לקבל דיווחים.",
    "Send activity emails" : "שליחת הודעות פעילות בדוא״ל",
    "As soon as possible" : "מהר ככל האפשר",
    "Hourly" : "שעתי",
    "Daily" : "יומי",
    "Weekly" : "שבועי",
    "You commented" : "הערות שלך",
    "Message deleted by author" : "ההודעה נמחקה על ידי מי שפרסם אותה",
    "Open {filename}" : "פתיחה (שם קובץ)",
    "in {path}" : "ב{path}",
    "Home" : "בית",
    "Could not load activities" : "לא ניתן לטעון פעילויות",
    "Loading activities" : "הפעילויות נטענות",
    "This stream will show events like additions, changes & shares" : "הזרמת מידע זו מראה אירועים כגון תוספות, שינויים ושיתופים",
    "No activity yet" : "אין עדיין פעילויות",
    "Loading more activities" : "נטענות פעילויות נוספות",
    "No more activities." : "אין פעילויות נוספות.",
    "Could not enable RSS link" : "לא ניתן להפעיל קישור RSS",
    "RSS link copied to clipboard" : "קישור ה־RSS ללוח הגזירים",
    "Could not copy the RSS link, please copy manually:" : "לא ניתן להעתיק את קובץ ה־RSS, נא להעתיק אותה ידנית:",
    "Activity settings" : "הגדרות פעילות",
    "Enable RSS feed" : "לאפשר הזנת RSS",
    "RSS feed" : "ערוץ RSS",
    "Copy RSS feed link" : "העתקת קישור לערוץ RSS",
    "Personal notification settings" : "הגדרות התראות אישיות",
    "Unable to load the activity list" : "לא ניתן לטעון את רשימת הפעילויות",
    "Choose for which activities you want to get an email or push notification." : "נא לבחור עבור אילו פעילויות מעניין אותך לקבל התראות בדוא״ל או בדחיפה.",
    "Choose for which activities you want to get a push notification." : "נא לבחור עבור אילו פעילויות מעניין אותך לקבל התראות בדחיפה.",
    "Notification" : "הוֹדָעָה",
    "Enable notification emails" : "הפעלת התראות בדוא״ל",
    "Daily activity summary" : "סיכום פעילות יומי",
    "Send daily activity summary in the morning" : "שלח סיכום יומי של הפעילויות כל בוקר",
    "Default settings" : "הגדרות ברירת מחדל",
    "Configure the default notification settings for new accounts." : "הגדרת תצורת ההתראות כברירת מחדל לחשבונות חדשים.",
    "Unable to save the settings" : "שמירת ההגדרות נכשלה",
    "No more events to load" : "אין אירועים נוספים לטעינה"
},
"nplurals=3; plural=(n == 1 && n % 1 == 0) ? 0 : (n == 2 && n % 1 == 0) ? 1: 2;");
